local AceGUI = LibStub("AceGUI-3.0")

---------------------------
-- Simple Dialog window  --
-- More complex than the --
-- Static Dialog...      --
---------------------------

--[[
	Events :
       OnClose(button)

]]
do
   local offset = 17
   local Type = "MDKP_BidDialog"
   local Version = 1
   
   local FrameBackdrop = {
      bgFile="Interface\\DialogFrame\\UI-DialogBox-Background",
      edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
      tile = true, tileSize = 32, edgeSize = 32, 
      insets = { left = 8, right = 8, top = 8, bottom = 8 }
   }
   
   local function frameOnClose(this)
      this.obj:Fire("OnClose")
   end
   
   local function EditBox_OnEnterPressed(this)
      this.obj:Fire("OnAccept")
   end
   
   local function OnBidPass(this)
      this.obj:Fire("OnBidPass")
   end
   
   local function SelectedGroup(this,event,value)
      this.parentgroup:Fire("OnPrioritySelected", value)
   end
   
   local function closeOnClick(this)
      this.obj:Hide()
   end

   local function SetPriorityList(this, value)
      if this.select.Clear then
	 this.select:Clear()
      end
      this.select:SetList(value)
   end
   
   local function frameOnMouseDown(this)
      this:GetParent():StartMoving()
   end
   
   local function frameOnMouseUp(this)
      local frame = this:GetParent()
      frame:StopMovingOrSizing()
   end
	
   local function SetText(self,text)
      self.label:SetText(text)
   end

   local function SetTitle(self, text, item)
      self.titletext:SetText(text)
      self.item = item
   end
   
   local function GetValue(self)
      return self.editbox:GetNumber()
   end
	 
   local function SetValue(self, value)
      if type(value) == "number" then
	 self.editbox:SetNumber(value)
      else
	 self.editbox:SetNumber(0)
      end
   end
	 
  local function Hide(self)
      self.frame:Hide()
   end
	
   local function Show(self)
      self.frame:Show()
   end
	
   local function Acquire(self)
      self.frame:SetParent(UIParent)
      self.frame:SetFrameStrata("FULLSCREEN_DIALOG")
      self.frame:Show()
   end
   
   local function Release(self)
      self.frame:Hide()
   end
   
   local function Constructor()
      local frame = CreateFrame("Frame",nil,UIParent)
      local self = {}
      self.type = "Frame"
      
      self.Hide = Hide
      self.Show = Show
      self.SetText =  SetText
      self.SetValue = SetValue
      self.GetValue = GetValue
      self.OnRelease = Release
      self.OnAcquire = Acquire
      self.SetTitle = SetTitle
      self.SetPriorityList = SetPriorityList
      
      self.frame = frame
      frame.obj = self
      frame:SetWidth(400)
      frame:SetHeight(130)
      frame:SetPoint("CENTER",UIParent,"CENTER",0,0)
      frame:EnableMouse()
      frame:SetMovable(true)
      frame:SetResizable(false)
      frame:SetFrameStrata("FULLSCREEN_DIALOG")
      
      frame:SetBackdrop(FrameBackdrop)
      frame:SetBackdropColor(0,0,0,1)
      frame:SetScript("OnHide",frameOnClose)
      frame:SetToplevel(true)

      local title = CreateFrame("Frame",nil,frame)
      self.title = title
      title:EnableMouse()
      title:SetScript("OnMouseDown",frameOnMouseDown)
      title:SetScript("OnMouseUp", frameOnMouseUp)
      
      local titlebg = frame:CreateTexture(nil,"OVERLAY")
      titlebg:SetTexture("Interface\\DialogFrame\\UI-DialogBox-Header")
      titlebg:SetTexCoord(0.31,0.67,0,0.63)
      titlebg:SetPoint("TOP",frame,"TOP",0,12)
      titlebg:SetWidth(100)
      titlebg:SetHeight(40)

      local titlebg_l = frame:CreateTexture(nil,"OVERLAY")
      titlebg_l:SetTexture("Interface\\DialogFrame\\UI-DialogBox-Header")
      titlebg_l:SetTexCoord(0.21,0.31,0,0.63)
      titlebg_l:SetPoint("RIGHT",titlebg,"LEFT",0,0)
      titlebg_l:SetWidth(30)
      titlebg_l:SetHeight(40)
      
      local titlebg_right = frame:CreateTexture(nil,"OVERLAY")
      titlebg_right:SetTexture("Interface\\DialogFrame\\UI-DialogBox-Header")
      titlebg_right:SetTexCoord(0.67,0.77,0,0.63)
      titlebg_right:SetPoint("LEFT",titlebg,"RIGHT",0,0)
      titlebg_right:SetWidth(30)
      titlebg_right:SetHeight(40)
      
      title:SetAllPoints(titlebg)			
      local titletext = title:CreateFontString(nil,"OVERLAY","GameFontNormal")
      titletext:SetPoint("TOP",titlebg,"TOP",0,-14)
      
      self.titletext = titletext	

      local labelFrame = CreateFrame("Frame", nil, frame)
      labelFrame:SetPoint("TOP",title,"BOTTOM",0,-2)
      labelFrame:SetWidth(frame:GetWidth()-offset*2)
      labelFrame:SetHeight(22)
      labelFrame:EnableMouse()
      labelFrame.obj = self
      
      local label = frame:CreateFontString(nil,"BACKGROUND","GameFontNormal")
      label:SetAllPoints(labelFrame)
      label:SetJustifyH("CENTER")
      label:SetJustifyV("TOP")
      self.label = label

      labelFrame:SetScript("OnEnter", function(this)
					 local self = this.obj
					 if self.item then
					    GameTooltip:SetOwner(this, "CURSOR")
					    GameTooltip:SetHyperlink(self.item)
					    GameTooltip:Show()
					 end
				      end)
      labelFrame:SetScript("OnLeave", function() GameTooltip:Hide() end)
      
      local centerFrame = CreateFrame("Frame", nil, frame)
      centerFrame:SetPoint("TOP", labelFrame, "BOTTOM", 0, -7)
      centerFrame.obj = self
      self.centerFrame = centerFrame
      
      local editbox = CreateFrame("EditBox", nil, frame, "InputBoxTemplate")
      editbox:SetAutoFocus(false)
      editbox:SetFontObject(ChatFontNormal)
--      editbox:SetScript("OnEscapePressed",function() frame:Hide() end)
      editbox:SetScript("OnEnterPressed", EditBox_OnEnterPressed)
      editbox:SetTextInsets(0,0,3,3)
      editbox:SetPoint("LEFT",centerFrame,"LEFT",0,0)
      editbox:SetHeight(19)
      editbox:SetWidth(80)

      self.editbox = editbox
      editbox.obj = self

      local select = AceGUI:Create("Dropdown")
      select.frame:SetPoint("RIGHT",centerFrame,"RIGHT",0, 0)
      select.frame:SetPoint("LEFT", editbox, "RIGHT", 10, 0)
      select.frame:SetParent(frame)
      select:SetCallback("OnValueChanged",SelectedGroup)
      select:SetLabel(nil)
      self.select = select
      select.parentgroup = self

      centerFrame:SetWidth(frame:GetWidth()-90)
      centerFrame:SetHeight(editbox:GetHeight()+10)
      
      local bid = CreateFrame("Button",nil,frame,"UIPanelButtonTemplate")
      bid:SetWidth(120)
      bid:SetHeight(20)
      bid:SetPoint("TOPRIGHT", centerFrame,"BOTTOM",-10,-7)
      bid:SetText("Send Bid")
      bid:SetScript("OnClick", EditBox_OnEnterPressed)
      bid:Show()
      
      self.bid = bid
      bid.obj = self
      
      local pass = CreateFrame("Button",nil,frame,"UIPanelButtonTemplate")
      pass:SetWidth(120)
      pass:SetHeight(20)
      pass:SetPoint("TOPLEFT", centerFrame,"BOTTOM",10,-7)
      pass:SetText("Pass")
      pass:SetScript("OnClick", OnBidPass)
      pass:Show()
		
      self.pass = pass
      pass.obj = self

      AceGUI:RegisterAsWidget(self)
      return self
   end
   
   AceGUI:RegisterWidgetType(Type,Constructor,Version)
end
